Product class

Constructors

Product({String? productId = '', String? name = '', String? brand = '', String? categoryName = '', List<String>? productCategories = const [], double price = 0.0, double salePrice = 0.0, String? currency = '', String? productLink = '', String? productImage = '', Map<String, dynamic>? extras = const <String, dynamic>{}})

Properties

brand → String?
final
categoryName → String?
final
currency → String?
final
extras → Map<String, dynamic>?
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
final
price → double
final
productCategories → List<String>?
final
productId → String?
final
productImage → String?
final
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
salePrice → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited